@@ -2,12 +2,12 @@
  *                   Material Object Library                   *
  *     Class Eshelby : declaration for the Eshelby tensor      *
  *                    simula+@metz.ensam.fr                    *
- *		     GNU/linux version 0.1.8                   *
+ *		     GNU/linux version 0.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006 COLLARD Christophe
- * copyright  2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2005,2006,2007 COLLARD Christophe
+ * copyright  2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class Eshelby
@@ -39,11 +39,11 @@
     We note \f$ C \f$ the elasticity tensor (see \ref isotropic_tensor), \f$ T^{II} \f$ the interaction tensor (see \ref TII) and V the inclusion volume. Then, Eshelby tensor reads \n
 \f$ \displaystyle S^{II}_{ijkl} = T^{II}_{ijpq} C_{pqkl} \f$.
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Christophe COLLARD \n
-            copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.1.8
-    \date 2005-2006
+    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2007 Christophe COLLARD \n
+            copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	    copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 0.2.0
+    \date 2005-2007
     \bug none
     \warning none
 */
@@ -206,8 +206,11 @@ template <class T> tensor4<T> Eshelby::penny_shape (const isotropic_elasticity_t
   \brief Computes Eshelby tensor 2323, 2332, 3223 and 3232 coordinates for oblate spheroid
 
   \f$ \displaystyle S^{II}_{2323} = S^{II}_{2332} = S^{II}_{3223} = S^{II}_{3232} = 
-  \frac{1}{2 (1-\nu)(a^2 - c^2)} \left[ a^2 - \nu (a^2 - c^2) + \frac{1}{2} \left( \displaystyle \frac{a^2 c \arccos \left( \frac{c}{a} \right)}{\sqrt{a^2 - c^2}} - c^2 \right) \left( \nu - \frac{2a^2 + c^2}{a^2 - c^2} \right) \right]. \f$
-
+  \frac{1}{2 (1-\nu)(a^2 - c^2)} \left[ a^2 - \nu (a^2 - c^2) + \frac{1}{2} \left( \displaystyle \frac{a^2 c \arccos \left( \frac{c}{a} \right)}{\sqrt{a^2 - c^2}} - c^2 \right) \left( \nu - \frac{2a^2 + c^2}{a^2 - c^2} \right) \right]. \f$ \n
+  If we note \f$ \zeta =  \displaystyle \frac{c}{a} \f$ then \n
+  \f$ \displaystyle S^{II}_{2323} =
+  \frac{1}{2 (1-\nu)(1 - \zeta^2)} \left[ 1 - \nu (1 - \zeta^2) + \frac{1}{2} \left( \displaystyle \frac{\zeta \arccos(\zeta)}{\sqrt{1 - \zeta^2}} - \zeta^2 \right) \left( \nu - \frac{2 + \zeta^2}{1 - \zeta^2} \right) \right]. \f$ \n
+  
   \param C elasticity tensor
   \param geometry penny shape length \f$ (a,a,c) \f$
   \return Eshelby tensor coordiantes 2323 2332 3223 3232
@@ -221,18 +224,13 @@ template <class T> T Eshelby::oblate_spheroid_2332 (const isotropic_elasticity_t
   assert (geometry[1] == geometry[2]);
 
   T nu = C.Poisson();
-  T a = geometry[1];
-  T a2 = a*a;
-  T c = geometry[3];
-  T c2 = c*c;
+  T zeta = geometry[3] / geometry[1];
+  assert (zeta < 1);
+  T zeta2 = pow(zeta,2);
+  T coef = 1/(1-zeta2);
 
-  assert (a > c);
-
-  T coef = a2-c2;
-
-  T Tii = .5 * ( a2 * c * acos(c/a) / sqrt(coef) - c2 ) * (nu - (2*a2 + c2) / coef);
-  Tii += a2 - nu*coef;
-  Tii *= .5 / ((1-nu)*coef);
+  T Tii = .5 * (coef-nu)  +  0.25 * zeta * coef * (nu - (2+zeta2)*coef) * (acos(zeta) * sqrt(coef) - zeta);
+  Tii /= (1-nu);
 
   return Tii;
 }
