@@ -2,12 +2,12 @@
  *                   Materials Object Library                  *
  *     Class MatOoLbox : declaration for materials toolbox     *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.1.0                   *
+ *                   GNU/linux version 0.1.2                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006 COLLARD Christophe
- * copyright  2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2005,2006,2007 COLLARD Christophe
+ * copyright  2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class MatOoLbox
@@ -36,11 +36,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Christophe COLLARD \n
-            copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.1.0
-    \date 2005-2006
+    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2007 Christophe COLLARD \n
+            copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	    copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 0.1.2
+    \date 2005-2007
     \bug none
     \warning none
 */
@@ -98,7 +98,7 @@ class MatOoLbox
 {
   template <class T> friend T Von_Mises_stress (const tensor2<T>&);
   template <class T> friend T Von_Mises_strain (const tensor2<T>&);
-  template <class T, template <class> class tensor_type> tensor2<T> constitutive_equation (const tensor_type<T>&, const tensor2<T>&, const tensor2<T>&, const T&, int);
+  template <class T, template <class> class tensor_type> friend tensor2<T> constitutive_equation (const tensor_type<T>&, const tensor2<T>&, const tensor2<T>&, const T&, int);
 };
 
 
@@ -153,12 +153,12 @@ template <class T> T Von_Mises_strain (const tensor2<T>& strain)
   \f$ \Sigma = L E - M T \f$, with \f$ T4 = L \; ; \; T2 = M \; ; \; stn = E \; ; \; str = \Sigma \; ; \; sgn = -1\f$. \n
   \f$ E = G \Sigma + N T \f$, with \f$ T4 = G \; ; \; T2 = N \; ;\; stn = \Sigma \; ;\; str = E \; ;\; sgn = 1 \f$. \n
 
-  \param str strain / stress tensor (E / \f$ \Sigma \f$)
+  \param str strain or stress tensor (E or \f$ \Sigma \f$)
   \param To temperature T
-  \param T4 L / G 4th order tensor
-  \param T2 M / N 2nd order tensor
-  \param sgn sign $\pm 1$
-  \return tsr stress / strain tensor
+  \param T4 L or G 4th order tensor
+  \param T2 M or N 2nd order tensor
+  \param sgn sign \f$ \pm 1 \f$
+  \return tsr stress or strain tensor
 */
 
 //----------------------------------------------------------------------------------------------------------------------------
