@@ -2,11 +2,11 @@
  *                   Materials Object Library                  *
  *Class cubic_tensor : declaration for cubic symmetry materials*
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.1.0                   *
+ *                   GNU/linux version 0.1.2                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2006 COLLARD Christophe
- * copyright  2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2006,2008 COLLARD Christophe
+ * copyright  2006,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
@@ -53,11 +53,11 @@
 	\f$ \n
 	and we get the following symmetries : \f$T_{ijkl} = T_{jikl} = T_{ijlk} = T_{klij} \f$.
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2006 Christophe COLLARD \n
-            copyright \htmlonly &#169; \endhtmlonly 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2006, 2008 Christophe COLLARD \n
+            copyright \htmlonly &#169; \endhtmlonly 2006, 2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
 	    copyright \htmlonly &#169; \endhtmlonly 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.1.0
-    \date 2006
+    \version 0.1.2
+    \date 2006-2008
     \bug none
     \warning none
 */
@@ -91,11 +91,11 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__TENSORS4_H)
-#include "../MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
 #endif
 
 using namespace std;
@@ -122,6 +122,7 @@ template <class T> class cubic_tensor : public tensor4<T>
     ~cubic_tensor () {}  // destructor
 
     string name(string = "");  // returns / computes tensor's name
+    vector<T> elastic_constants ();
     cubic_tensor<T> inv ();
 
     template <class Tf> friend ostream& operator << (ostream&, cubic_tensor<Tf>&);
@@ -238,7 +239,7 @@ template <class T> cubic_tensor<T>::cubic_tensor (const tensor4<T>& t, string na
 
 
 /*!
-  \brief Changes and/or returns tensor name
+  \brief Changes and/or returns tensor name.
   \param name tensor name
   \return tensor name
 */
@@ -253,6 +254,24 @@ template <class T> string cubic_tensor<T>::name (string name)
 }
 
 
+/*!
+  \brief Returns elastic constants.
+  \return \f$ (c_{11}, c_{44}, c_{12}) \f$
+*/
+
+//----------------------------------------------------------------
+template <class T> vector<T> cubic_tensor<T>::elastic_constants ()
+//----------------------------------------------------------------
+{
+  vector<T> constants (3,false);
+  constants[1] = C11;
+  constants[2] = C44;
+  constants[3] = C12;
+
+  return constants;
+}
+
+
 /*!
   \brief Computes the inverse of a \f$ \displaystyle 4^{th} \f$ order cubic tensor.
 
