@@ -2,13 +2,13 @@
  *                   Materials Object Library                  *
  * Class isotropic_tensor : declaration for isotropic material *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.5.2                   *
+ *                   GNU/linux version 0.5.6                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2002,2003,2004,2005,2006 COLLARD Christophe
+ * copyright  2002,2003,2004,2005,2006,2007,2008 COLLARD Christophe
  * copyright  2006 PARGUEZ Cristelle
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2002,2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*! \class isotropic_tensor
@@ -40,12 +40,12 @@
     Let \f$ \lambda \f$ and \f$ \mu \f$ be two constants. We define a \f$ 4^{th} \f$ order isotropic tensor \f$ \bold{C} \f$ through \f$ \lambda \f$ and \f$ \mu \f$ by \n
     \f$ C_{ijkl} = \lambda \delta_{ij} \delta_{kl} + \mu (\delta_{ik} \delta_{jl} + \delta_{il} \delta_{jk}) \f$
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Christophe COLLARD \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
             copyright \htmlonly &#169; \endhtmlonly 2006 Cristelle PARGUEZ \n
-            copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.5.2
-    \date 2002-2006
+            copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
+	    copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+    \version 0.5.6
+    \date 2002-2008
     \bug none
     \warning none
 */
@@ -79,11 +79,15 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../MOL++/vectors.h"
+#include "MOL++/vectors.h"
+#endif
+
+#if !defined(__MATRIX_H)
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__TENSOR4_H)
-#include "../MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
 #endif
 
 using namespace std;
@@ -110,6 +114,7 @@ template <class T> class isotropic_tensor
     string name();      // returns tensor's name
     virtual T lambda (T);
     virtual T mu     (T);
+    vector<T> elastic_constants ();
 
     // returns constants
     T lambda () const {return Lambda;}
@@ -121,8 +126,8 @@ template <class T> class isotropic_tensor
     tensor3<T> operator [] (int) const; // returns a 3rd order tensor Cijkl -> Tjkl
     template <class Tf> friend isotropic_tensor<Tf> operator + (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);// overloads operator + for 4th order isotropic tensors
     template <class Tf> friend isotropic_tensor<Tf> operator - (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);// overloads operator - for 4th order isotropic tensors
-    template <class Tf> friend Tf operator | (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);
-    template <class Tf> friend isotropic_tensor<Tf> operator || (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);
+    template <class Tf> friend Tf operator | (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);  // T_ijkl  R_ijkl
+    template <class Tf> friend isotropic_tensor<Tf> operator || (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);  // P_ijkl = T_ijpq R_pqkl 
     isotropic_tensor<T>& operator += (const isotropic_tensor<T>&);  // overloads += operator for isotropic tensors
     isotropic_tensor<T>& operator -= (const isotropic_tensor<T>&);  // overloads -= operator for isotropic tensors
     // operations with scalars
@@ -130,17 +135,17 @@ template <class T> class isotropic_tensor
     template <class Tf> friend isotropic_tensor<Tf> operator * (const Tf&, const isotropic_tensor<Tf>&);
     isotropic_tensor<T>& operator *= (const T&);
     // operations withs vectors
-    template <class Tf> friend tensor3<Tf> operator * (const isotropic_tensor<Tf>&, const vector<Tf>&);
-    template <class Tf> friend tensor3<Tf> operator * (const vector<Tf>&, const isotropic_tensor<Tf>&);
-    template <class Tf> friend tensor3<Tf> operator | (const isotropic_tensor<Tf>&, const vector<Tf>&);
-    template <class Tf> friend tensor3<Tf> operator | (const vector<Tf>&, const isotropic_tensor<Tf>&);
-    template <class Tf> friend tensor3<Tf> tensor_sum (const isotropic_tensor<Tf>&, const vector<Tf>&, int);
+    template <class Tf> friend tensor3<Tf> operator * (const isotropic_tensor<Tf>&, const vector<Tf>&);  // P_ijk = T_ijkl * V_l
+    template <class Tf> friend tensor3<Tf> operator * (const vector<Tf>&, const isotropic_tensor<Tf>&);  // P_jkl = T_ijkl * V_i
+    template <class Tf> friend tensor3<Tf> operator | (const isotropic_tensor<Tf>&, const vector<Tf>&);  // P_ijl = T_ijkl * V_k
+    template <class Tf> friend tensor3<Tf> operator | (const vector<Tf>&, const isotropic_tensor<Tf>&);  // P_ikl = T_ijkl * V_j
+    template <class Tf> friend tensor3<Tf> tensor_sum (const isotropic_tensor<Tf>&, const vector<Tf>&, int);  // P = T : v
     // operation with 2nd order tensor
-    template <class Tf> friend tensor2<Tf> operator || (const isotropic_tensor<Tf>&, const tensor2<Tf>&);
-    template <class Tf> friend tensor2<Tf> operator || (const tensor2<Tf>&, const isotropic_tensor<Tf>&);
+    template <class Tf> friend tensor2<Tf> operator || (const isotropic_tensor<Tf>&, const tensor2<Tf>&);  // P_ij = T_ijkl * M_kl
+    template <class Tf> friend tensor2<Tf> operator || (const tensor2<Tf>&, const isotropic_tensor<Tf>&);  // P_kl = M_ij * T_ijkl
     // operation with 3rd order tensor
-    template <class Tf> friend tensor3<Tf> operator || (const isotropic_tensor<Tf>&, const tensor3<Tf>&);
-    template <class Tf> friend tensor3<Tf> operator || (const tensor3<Tf>&, const isotropic_tensor<Tf>&);
+    template <class Tf> friend tensor3<Tf> operator || (const isotropic_tensor<Tf>&, const tensor3<Tf>&);  // P_n,ij = T_ijkl R_n,kl
+    template <class Tf> friend tensor3<Tf> operator || (const tensor3<Tf>&, const isotropic_tensor<Tf>&);  // P_n,ij = R_n,kl T_klij
     // operations with 4rd order tensor
     template <class Tf> friend tensor4<Tf> operator + (const isotropic_tensor<Tf>&, const tensor4<Tf>&);
     template <class Tf> friend tensor4<Tf> operator + (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
@@ -150,7 +155,7 @@ template <class T> class isotropic_tensor
     template <class Tf> friend Tf operator | (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
     template <class Tf> friend tensor4<Tf> operator || (const isotropic_tensor<Tf>&, const tensor4<Tf>&);
     template <class Tf> friend tensor4<Tf> operator || (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
-    template <class Tf> friend bool operator == (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);// compares 2 isotropic tensors
+    template <class Tf> friend bool operator == (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);  // compares 2 isotropic tensors
     template <class Tf> friend bool operator != (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);
     template <class Tf> friend bool operator == (const isotropic_tensor<Tf>&, const tensor4<Tf>&);
     template <class Tf> friend bool operator == (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
@@ -158,6 +163,8 @@ template <class T> class isotropic_tensor
     template <class Tf> friend bool operator != (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
 
     isotropic_tensor<T> inv ();
+    template <class Tf> friend isotropic_tensor<Tf> change_basis (const matrix<Tf>&, const isotropic_tensor<Tf>&, bool); // for orthogonal matrix
+    template <class Tf> friend tensor4<Tf> change_basis (const matrix<Tf>&, const isotropic_tensor<Tf>&);
 
     template <class Tf> friend ostream& operator << (ostream&, const isotropic_tensor<Tf>&);
     template <class Tf> friend istream& operator >> (istream&, isotropic_tensor<Tf>&);
@@ -331,6 +338,23 @@ template <class T> T isotropic_tensor<T>::mu (T mu)
 }
 
 
+/*!
+  \brief Returns elastic constants.
+  \return \f$ (\lambda, \mu) \f$
+*/
+
+//--------------------------------------------------------------------
+template <class T> vector<T> isotropic_tensor<T>::elastic_constants ()
+//--------------------------------------------------------------------
+{
+  vector<T> lame_constants (2,false);
+  lame_constants[1] = Lambda;
+  lame_constants[2] = Mu;
+
+  return lame_constants;
+}
+
+
 /*!
   \brief Returns an element of a \f$ \displaystyle 4^{th} \f$ order isotropic tensor.
 
@@ -1168,6 +1192,55 @@ template <class T> isotropic_tensor<T> isotropic_tensor<T>::inv ()
 }
 
 
+/*!
+  \brief Computes the change of basis for a \f$ 4^{th} \f$ order isotropic tensor and an orthogonal change of basis matrix.
+
+  \f$ \displaystyle C^\prime_{pqmn} = \left[ \lambda P_{pi} P_{qi} P_{mj} P_{nj}  + \mu \left( P_{pi} P_{qj} P_{mi} P_{nj} + P_{pi} P_{qj} P_{mj} P_{ni} \right) \right] \f$. \n
+  When \f$ P \f$ is an orthogonal matrix (i.e. \f$ P^{-1} = P^t \f$) we get \f$ C^\prime_{pqmn} = C_{pqmn} \f$ .
+  \param P orthogonal change of basis matrix
+  \param tsr isotropic tensor in the old basis
+  \return \f$ C^\prime \f$ isotropic tensor in the new basis
+*/
+
+//----------------------------------------------------------------------------------------------------------------------------
+template <class Tf> isotropic_tensor<Tf> change_basis (const matrix<Tf>& P, const isotropic_tensor<Tf>& tsr, bool Porthogonal)
+//----------------------------------------------------------------------------------------------------------------------------
+{
+  assert (Porthogonal);
+  assert ((P.Rows() ==3) && (P.Columns() == 3));
+  assert (t(P) == gauss(P));
+  
+  return tsr;
+}
+
+
+/*!
+  \brief Computes the change of basis for a \f$ 4^{th} \f$ order isotropic tensor.
+
+  \f$ \displaystyle C^\prime_{pqmn} = \left[ \lambda P_{pi} P_{qi} P_{mj} P_{nj}  + \mu \left( P_{pi} P_{qj} P_{mi} P_{nj} + P_{pi} P_{qj} P_{mj} P_{ni} \right) \right] \f$. \n
+  \param P change of basis matrix
+  \param tsr isotropic tensor in the old basis
+  \return \f$ C^\prime \f$ isotropic tensor in the new basis
+*/
+
+//-------------------------------------------------------------------------------------------------
+template <class Tf> tensor4<Tf> change_basis (const matrix<Tf>& P, const isotropic_tensor<Tf>& tsr)
+//-------------------------------------------------------------------------------------------------
+{
+  assert ((P.Rows() ==3) && (P.Columns() == 3));
+
+  tensor2<Tf> PPt =& (P * t(P)).approximation();
+  tensor4<Tf> C =& ( tsr.Lambda * (PPt ^ PPt) );
+  for (int p=1; p<=3; p++)
+    for (int q=1; q<=3; q++)
+      for (int m=1; m<=3; m++)
+	for (int n=1; n<=3; n++)
+	  C(p,q,m,n) += tsr.Mu * ( PPt(p,m) * PPt(q,n) + PPt(p,n) * PPt(q,m) );
+
+  return C;
+}
+
+
 //------------------------------------------------------------------------------------
 template <class Tf> ostream& operator << (ostream& s, const isotropic_tensor<Tf>& tsr)
 //------------------------------------------------------------------------------------
