@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.1.8                   *
+ *	             GNU/linux version 0.2.2                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006 COLLARD Christophe
- * copyright  2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2005,2006,2007 COLLARD Christophe
+ * copyright  2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -48,35 +48,35 @@
 #endif
 
 #if !defined(__PARAMETERS_H)
-#include "../../parameters.h"
+#include "parameters.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include"../../MOL++/matrix.h"
+#include"MOL++/matrix.h"
 #endif
 
 #if !defined(__TENSORS2_H)
-#include"../../MOL++/tensors2.h"
+#include"MOL++/tensors2.h"
 #endif
 
 #if !defined(__TENSORS3_H)
-#include"../../MOL++/tensors3.h"
+#include"MOL++/tensors3.h"
 #endif
 
 #if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
-#include"../../MateriOL++/isotropic elasticity tensors.h"
+#include"MateriOL++/isotropic elasticity tensors.h"
 #endif
 
 #if !defined(__TII_H)
-#include"../../MateriOL++/TII.h"
+#include"MateriOL++/TII.h"
 #endif
 
 #if !defined(__ESHELBY_H)
-#include"../../MateriOL++/Eshelby.h"
+#include"MateriOL++/Eshelby.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -151,8 +151,8 @@ int test_Eshelby (int detail)
   else result *= (test);
 
   geometry[3] = R-5.e-4;
-  test = abs(SII.ellipsoid(C,geometry,13,17)(2,3,3,2) -  SII.oblate_spheroid_2332(C,geometry)) < 2.e-6;
-  test *= abs(Siso_analytique(2,3,3,2) -  SII.oblate_spheroid_2332(C,geometry)) < 6.e-6;
+  test = abs(SII.ellipsoid(C,geometry,13,17)(2,3,3,2) -  SII.oblate_spheroid_2332(C,geometry)) < 4.e-6;
+  test *= abs(Siso_analytique(2,3,3,2) -  SII.oblate_spheroid_2332(C,geometry)) < 6.e-7;
   if (detail) affiche ("oblate / sphere (coord 2332)", test);
   else result *= (test);
 
