@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.1.8                   *
+ *	             GNU/linux version 0.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006 COLLARD Christophe
- * copyright  2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2005,2006,2007 COLLARD Christophe
+ * copyright  2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -48,27 +48,27 @@
 #endif
 
 #if !defined(__PARAMETERS_H)
-#include "../../parameters.h"
+#include "parameters.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include"../../MOL++/matrix.h"
+#include"MOL++/matrix.h"
 #endif
 
 #if !defined(__TENSORS4_H)
-#include"../../MOL++/tensors4.h"
+#include"MOL++/tensors4.h"
 #endif
 
 #if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
-#include"../../MateriOL++/isotropic elasticity tensors.h"
+#include"MateriOL++/isotropic elasticity tensors.h"
 #endif
 
 #if !defined(__TII_H)
-#include"../../MateriOL++/TII.h"
+#include"MateriOL++/TII.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
