@@ -1,12 +1,12 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.2.8                   *
+ *	             GNU/linux version 0.3.6                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006 COLLARD Christophe
+ * copyright  2003,2004,2005,2006,2007,2008 COLLARD Christophe
  * copyright  2006 PARGUEZ Cristelle
- * copyright  2003,2004,2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -49,23 +49,27 @@
 #endif
 
 #if !defined(__PARAMETERS_H)
-#include "../../parameters.h"
+#include "parameters.h"
 #endif
 
 #if !defined(___VECTORS_H)
-#include"../../MOL++/vectors.h"
+#include"MOL++/vectors.h"
+#endif
+
+#if !defined(___MATRIX_H)
+#include"MOL++/matrix.h"
 #endif
 
 #if !defined(___TENSOR4_H)
-#include"../../MOL++/tensors4.h"
+#include"MOL++/tensors4.h"
 #endif
 
 #if !defined(__ISOTROPIC_TENSORS_H)
-#include"../../MateriOL++/isotropic tensors.h"
+#include"MateriOL++/isotropic tensors.h"
 #endif
 
 #if !defined(__AFFICHE_h)
-#include "../affiche.h"
+#include "tests/affiche.h"
 #endif
 
 
@@ -86,6 +90,12 @@ int test_isotropic_tensor (int detail)
   else result *= (C.lambda()==60000 && C.mu()==40000);
   bool test = true;
 
+  vector<long double> lame(2);
+  lame[1] = C.lambda();
+  lame[2] = C.mu();
+  if (detail) affiche ("elastic constants", C.elastic_constants() == lame);
+  else result *= (C.elastic_constants() == lame);
+
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
       for (int k=1; k<=3; k++)
@@ -420,6 +430,39 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("isotropic stiffness tensor", St==S && S==C0.inv());
   else result *= (St==S && S==C0.inv());
 
+  matrix<long double> P(3,3);
+  matrix<long double> passlg(3,3); // orthogonal matrix
+  tensor4<long double> tsr(3);
+  for (int i=1; i<=3; i++)
+    for (int j=1; j<=3; j++)
+      P(i,j) = (2.52*i - 1.25*j + 25 * (i==j)) * 1E-2;
+  long double phi1=173.464, phi=104.504, phi2=34.5;
+  passlg(1,1) =  cos(phi1) * cos(phi2)  -  sin(phi1) * cos(phi) * sin(phi2);
+  passlg(1,2) = -cos(phi1) * sin(phi2)  -  sin(phi1) * cos(phi) * cos(phi2);
+  passlg(1,3) =  sin(phi1) * sin(phi);
+  passlg(2,1) =  sin(phi1) * cos(phi2)  +  cos(phi1) * cos(phi) * sin(phi2);
+  passlg(2,2) = -sin(phi1) * sin(phi2)  +  cos(phi1) * cos(phi) * cos(phi2);
+  passlg(2,3) = -cos(phi1) * sin(phi);
+  passlg(3,1) =  sin(phi)  * sin(phi2);
+  passlg(3,2) =  sin(phi)  * cos(phi2);
+  passlg(3,3) =  cos(phi);
+  for (int i=1; i<=3; i++)
+    for (int j=1; j<=3; j++)
+      for (int k=1; k<=3; k++)
+	for (int l=1; l<=3; l++)
+	  for (int p=1; p<=3; p++)
+	    for (int q=1; q<=3; q++)
+	      for (int m=1; m<=3; m++)
+		for (int n=1; n<=3; n++)
+		  tsr(p,q,m,n) += P(p,i) * P(q,j) * P(m,k) * P(n,l) * C(i,j,k,l);
+  long double scalar = .01;
+  test = true;
+  test *= (C == change_basis(passlg,C,true));
+  test *= (C*scalar == change_basis(passlg,C)*scalar);
+  test *= (tsr == change_basis(P,C));
+  if (detail) affiche ("change basis", test);
+  else result *= test;
+
   C.save ("isotropic tensor.res");
   C0.read ("isotropic tensor.res");
   isotropic_tensor<long double> Ciso;
