@@ -1,12 +1,12 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.1.6                   *
+ *	             GNU/linux version 0.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006 COLLARD Christophe
+ * copyright  2005,2006,2007,2008 COLLARD Christophe
  * copyright  2005,2006 BERBENNI Stephane
- * copyright  2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 /*
@@ -49,6 +49,10 @@
 #endif
 
 #if !defined(__ASSERT_H)
+#include <assert.h>
+#endif
+
+#if !defined(__TIME_H)
 #include <time.h>
 #endif
 
@@ -68,6 +72,10 @@
 #include"cubic elasticity tensors-test.h"
 #endif
 
+#if !defined(__ORTHOTROPIC_TENSORS_TEST_H)
+#include"orthotropic tensors-test.h"
+#endif
+
 #if !defined(__TII_TEST_H)
 #include"TII-test.h"
 #endif
@@ -142,6 +150,18 @@ main()
 
   cout << endl;
 
+  detail = 0;
+  start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "----------------------orthotropic tensor----------------------\n";
+    //=======================================================================
+  result *= test_orthotropic_tensor(detail);
+  end = clock();
+  cout << "cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
   detail = 0;
   start = clock();
   if (detail)
